@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/blmixi.F
+! source file: /usr/local/models/UVic_ESCM/2.7/source/mom/blmixi.F
       subroutine blmixi
 
 !-----------------------------------------------------------------------
@@ -28,7 +28,9 @@
 
       do k=1,km
         Ahv(k) = (afkph + (dfkph/pi)*(atan(sfkph*(zw(k) - zfkph))))
-      end do
+      enddo
+
+      Ahh = 0.
 
       write (stdout,'(/a/)')
      &  'B R Y A N - L E W I S   M I X I N G   C O E F F S'
