@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/diago.F
+! source file: /usr/local/models/UVic_ESCM/2.7/source/mom/diago.F
       subroutine diago
 
 !=======================================================================
@@ -8,6 +8,7 @@
 !=======================================================================
 
       include "param.h"
+      include "calendar.h"
       include "ctmb.h"
       include "coord.h"
       include "cprnts.h"
@@ -30,13 +31,15 @@
       include "vmixc.h"
 !#define debug_extmode
 
-      character(80) :: ftsi, ftbt, file_stamp
+      character(120) :: ftsi, ftbt, file_stamp
       save ftsi, ftbt
       data ftsi  /' '/
       data ftbt  /' '/
 
       integer ntrec
 
+      real time
+
 !-----------------------------------------------------------------------
 !     compute tracer averages under horizontal regions and write them
 !     out
@@ -170,34 +173,39 @@
 !     print integrals for monitoring the time step
 !-----------------------------------------------------------------------
 
-      if (tsiperts .and. eots) call ta_ocn_tsi (1)
+      if (tsiperts .and. eots) call ta_mom_tsi (1)
 
       if (tsits .and. ntatio .gt. 0) then
-        call ta_ocn_tsi (2)
+        call ta_mom_tsi (2)
 
         if (iotsi .eq. stdout .or. iotsi .lt. 0) then
           write (stdout,9601) itt, stamp, tai_ek, tai_dt, tai_ds, tai_t
      &,                       tai_s, tai_tvar, tai_svar, tai_scan
         endif
         if (iotsi .ne. stdout .or. iotsi .lt. 0) then
-          reltim = prelyr
 
           if (iotsi .ne. stdout) then
             ntrec = 1
-            if (ftsi .eq. ' ') ntrec = 0
-
-            if (ftsi .eq. ' ')
-     &        ftsi = file_stamp ('ts_intgrls',stamp,'.nc')
-
-            avgper = dtts*ntatio/86400.0
-            call ocn_tsi_out (ftsi, ntrec, timunit, expnam, avgper
-     &,                       relyr, stamp, tai_ek, tai_t, tai_s
+            if (ftsi .eq. ' ') then
+              ntrec = 0
+              ftsi = file_stamp ('ts_intgrls_mom',stamp,'.nc')
+            endif
+            avgper = dtts*ntatio/daylen
+            time = relyr + year0
+            call mom_tsi_out (ftsi, ntrec, timunit, expnam, avgper
+     &,                       time, stamp, tai_ek, tai_t, tai_s
      &,                       tai_tvar, tai_svar, tai_dt, tai_ds
-     &,                       tai_scan, tai_otmax, tai_otmin)
+     &,                       tai_scan
+
+     &,                       tai_dic
+
+     &,                       tai_otmax, tai_otmin
+
+     &                       )
           endif
         endif
 
-        call ta_ocn_tsi (0)
+        call ta_mom_tsi (0)
       endif
 9601  format (1x,'ts=',i7, 1x, a32, ', ke=', 1pe13.6,' |dT|=',1pe13.6
      &,      ' |dS|=',1pe13.6,' Tbar=',1pe13.6,' Sbar=',1pe13.6
@@ -888,9 +896,7 @@
 
           do m=0,nhreg
             do jrow=1,jmt
-
               do ll=6,8
-
                 ttn2(ll,jrow,1,m) = ttn2(ll,jrow,1,m)*4.186e-15
                 ttn2(ll,jrow,2,m) = ttn2(ll,jrow,2,m)*1.e-10
               enddo
@@ -906,9 +912,7 @@
             endif
             write (stdout,8203)
             do jrow=1,jmt
-
               write (stdout,8204) jrow,(ttn2(i,jrow,1,m),i=6,8)
-
             enddo
           enddo
 
@@ -921,9 +925,7 @@
             endif
             write (stdout,8203)
             do jrow=1,jmt
-
               write (stdout,8204) jrow,(ttn2(i,jrow,2,m),i=6,8)
-
             enddo
           enddo
         endif
@@ -949,7 +951,6 @@
      &    'read (iogyre) (((ttn2(6..8,1..jmt,1..2,0..nhreg)'
           write (io) pstamp, iotext, expnam
           len = 3*jmt*nt*(1+nhreg)
-
           call wrufio (io, ttn2, len)
 
           call relunit (io)
@@ -964,10 +965,8 @@
 82001 format (/,6x,'northward transport of heat (x10**15 watts)',/)
 8201  format (/,22x,a40,/)
 8202  format (/,22x,' Global ',/)
-
 8203  format (8x,'total advection',2x,'total diffusion',2x,'total')
 8204  format (2x,i3,3x,3(e12.6,5x))
-
 8205  format (/,6x,'northward transport of salt (x10**10 cm**3/sec)',/)
 
 !-----------------------------------------------------------------------
@@ -984,9 +983,7 @@
           write (stdout,8194)
           js = indp (slatxy, yt, jmt)
           je = indp (elatxy, yt, jmt)
-
           call matrix (vmsf, jmt, js, je, 1, km, scl)
-
         endif
         if (iovmsf .ne. stdout .or. iovmsf .lt. 0) then
           reltim = prelyr
@@ -1015,7 +1012,6 @@
           call wrufio (io, vmsf, jmt*km)
 
           call relunit (io)
-
         endif
       endif
 8194  format(/,' meridional overturning stream function (sverdrups)')
@@ -1031,7 +1027,7 @@
       return
       end
 
-      subroutine ta_ocn_tsi (m)
+      subroutine ta_mom_tsi (m)
 
 !=======================================================================
 !     ocean data time integral averaging
@@ -1039,17 +1035,30 @@
 !     input:
 !       m = flag (0 = zero, 1 = accumulate, 2 = write)
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
 !      implicit none
 
       include "param.h"
       include "coord.h"
+      include "cregin.h"
+      include "grdvar.h"
       include "diag.h"
       include "emode.h"
+      include "levind.h"
+      include "mw.h"
+      include "iounit.h"
 
-      real rntatio, sum, tmp
+      integer i, j, jrow, k, ib(10), ic(10)
+
+      include "state.h"
+      include "dens.h"
+
+      real d, dens, dins, rntatio, s, sum, tmp, tins, tinsit
+      real C2K, p001, p035
+
+      real otsf(km)
 
 !-----------------------------------------------------------------------
 !     time averaged integrated data
@@ -1058,6 +1067,10 @@
       if (m .eq. 0.) then
 !       zero
         ntatio = 0
+
+        nv_otsf = 0
+        v_otsf(:,:) = 0.
+
         tai_ek = 0.
         tai_t = 0.
         tai_s = 0.
@@ -1068,10 +1081,13 @@
         tai_scan = 0.
         tai_otmax = 0.
         tai_otmin = 0.
-        v_otsf(:,:,:) = 0.
+
+        tai_dic = 0.
+
       elseif (m .eq. 1) then
 !       accumulate
         ntatio = ntatio + 1
+
         do j=2,jmtm1
           do k=km,1,-1
             ektot(0,1) = ektot(0,1) + ektot(k,j)
@@ -1090,36 +1106,41 @@
           travar(0,n,1) = travar(0,n,1)/tcellv - tbar(0,n,1)**2
           dtabs(0,n,1) = dtabs(0,n,1)/tcellv
         enddo
-        do j=jsot,jeot
-          do k=1,km
-            v_otsf(j,k,2) = v_otsf(j,k,2) +  v_otsf(j,k,1)
-           enddo
-        enddo
         tai_ek = tai_ek + ektot(0,1)
-        tai_t = tai_t + tbar(0,1,1)
-        tai_s = tai_s + tbar(0,2,1)
-        tai_tvar = tai_tvar + travar(0,1,1)
-        tai_svar = tai_svar + travar(0,2,1)
-        tai_dt = tai_dt + dtabs(0,1,1)
-        tai_ds = tai_ds + dtabs(0,2,1)
+        tai_t = tai_t + tbar(0,itemp,1)
+        tai_s = tai_s + tbar(0,isalt,1)
+        tai_tvar = tai_tvar + travar(0,itemp,1)
+        tai_svar = tai_svar + travar(0,isalt,1)
+        tai_dt = tai_dt + dtabs(0,itemp,1)
+        tai_ds = tai_ds + dtabs(0,isalt,1)
         tai_scan = tai_scan + mscan
+
+        tai_dic = tai_dic + tbar(0,idic,1)
+
       elseif (m .eq. 2 .and. ntatio .ne. 0) then
 !       average
         rntatio = 1./float(ntatio)
-        tai_otmax = -1.e20
-        tai_otmin = 1.e20
-        do j=jsot,jeot
-          do k=1,km
-            v_otsf(j,k,2) = v_otsf(j,k,2)*rntatio
+
+        if (nv_otsf .gt. 0) then
+          rnv_otsf = 1./float(nv_otsf)
+          tai_otmax = -1.e20
+          tai_otmin = 1.e20
+          do j=jsot,jeot
+            do k=1,km
+              v_otsf(j,k) = v_otsf(j,k)*rnv_otsf*dzt(k)*csu(j)
+            enddo
+!           integrate up from the bottom
+            otsf(km) = 0.
+            do k=km-1,1,-1
+              otsf(k) = otsf(k+1) - v_otsf(j,k)
+            enddo
+            do k=ksot,keot
+              if (otsf(k) .gt. tai_otmax) tai_otmax = otsf(k)
+              if (otsf(k) .lt. tai_otmin) tai_otmin = otsf(k)
+            enddo
           enddo
-          do k=2,km
-            v_otsf(j,k,1) = v_otsf(j,k-1,1) + v_otsf(j,k-1,2)*dzt(k-1)
-          enddo
-          do k=ksot,keot
-            if (v_otsf(j,k,1) .gt. tai_otmax) tai_otmax = v_otsf(j,k,1)
-            if (v_otsf(j,k,1) .lt. tai_otmin) tai_otmin = v_otsf(j,k,1)
-          enddo
-        enddo
+        endif
+
         tai_ek = tai_ek*rntatio
         tai_t = tai_t*rntatio
         tai_s = tai_s*rntatio
@@ -1128,7 +1149,10 @@
         tai_dt = tai_dt*rntatio
         tai_ds = tai_ds*rntatio
         tai_scan = tai_scan*rntatio
-       endif
+
+        tai_dic = tai_dic*rntatio
+
+      endif
 
       return
       end
