@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/grids.F
+! source file: /usr/local/models/UVic_ESCM/2.7/source/common/grids.F
       subroutine gcoord (maxlen, imt, jmt, km, dxtdeg, dytdeg, dxudeg
      &,                  dyudeg, dzt, dzw, xt, xu, yt, yu, zt, zw)
 
@@ -33,21 +33,25 @@
 !     zt     = depth at centers of "t" grid cells (centimeters)
 !     zw     = depth at centers of "u" grid cells (centimeters)
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       include "stdunits.h"
       parameter (maxbounds=11)
-      dimension xt(maxlen), yt(maxlen), xu(maxlen), yu(maxlen)
-      dimension zw(maxlen), zt(maxlen)
+      dimension xt(imt), yt(jmt), xu(imt), yu(jmt)
+      dimension zw(km), zt(km)
 
-      dimension dxtdeg(maxlen), dytdeg(maxlen), dzt(maxlen)
-      dimension dxudeg(maxlen), dyudeg(maxlen), dzw(0:maxlen)
+      dimension dxtdeg(imt), dytdeg(jmt), dzt(km)
+      dimension dxudeg(imt), dyudeg(jmt), dzw(0:km)
 
       dimension x_lon(maxbounds),   dx_lon(maxbounds)
       dimension y_lat(maxbounds),   dy_lat(maxbounds)
       dimension z_depth(maxbounds), dz_depth(maxbounds)
 
+      integer ib(10), ic(10)
+      character(120) :: fname, new_file_name
+      logical exists
+
 !-----------------------------------------------------------------------
 !     USER INPUT ===>  read this section and specify the grid.
 !-----------------------------------------------------------------------
@@ -230,22 +234,54 @@
       ncase = 0
 
       ncase = ncase + 1
-      time = 0.
-      ntrec = 1
-      call openfile ("data/grid.nc", time, ntrec, iou)
-      call getvara ('dxt', iou, imt, (/1/), (/imt/), dxtdeg, 1., 0.)
-      call getvara ('dyt', iou, jmt, (/1/), (/jmt/), dytdeg, 1., 0.)
-      call getvara ('dxu', iou, imt, (/1/), (/imt/), dxudeg, 1., 0.)
-      call getvara ('dyu', iou, jmt, (/1/), (/jmt/), dyudeg, 1., 0.)
-      call getvara ('dzt', iou, km, (/1/), (/km/), dzt(1:km), 1., 0.)
-      call getvara ('dzw', iou, km, (/1/), (/km/), dzw(1:km), 1., 0.)
-      call getvara ('xt', iou, imt, (/1/), (/imt/), xt, 1., 0.)
-      call getvara ('yt', iou, jmt, (/1/), (/jmt/), yt, 1., 0.)
-      call getvara ('xu', iou, imt, (/1/), (/imt/), xu, 1., 0.)
-      call getvara ('yu', iou, jmt, (/1/), (/jmt/), yu, 1., 0.)
-      call getvara ('zt', iou, km, (/1/), (/km/), zt(1:km), 1., 0.)
-      call getvara ('zw', iou, km, (/1/), (/km/), zw(1:km), 1., 0.)
+      c0 = 0.
+      c1 = 1.
+      c100 = 100.
+      fname = new_file_name ("grid.nc")
+      inquire (file=trim(fname), exist=exists)
+      if (.not. exists) then
+        print*, "Error => ", trim(fname), " does not exist."
+        stop 'gcoord in grids.f'
+      endif
+      dxtdeg(:) = c0
+      dytdeg(:) = c0
+      dxudeg(:) = c0
+      dyudeg(:) = c0
+      dzt(:) = c0
+      dzw(:) = c0
+      xt(:) = c0
+      yt(:) = c0
+      xu(:) = c0
+      yu(:) = c0
+      zt(:) = c0
+      zw(:) = c0
+      ib(:) = 1
+      call openfile (fname, iou)
+      ic(:) = imt
+      call getvara ('dxt', iou, imt, ib, ic, dxtdeg, c1, c0)
+      call getvara ('dxu', iou, imt, ib, ic, dxudeg, c1, c0)
+      call getvara ('xt', iou, imt, ib, ic, xt, c1, c0)
+      call getvara ('xu', iou, imt, ib, ic, xu, c1, c0)
+      ic(1) = jmt
+      call getvara ('dyt', iou, jmt, ib, ic, dytdeg, c1, c0)
+      call getvara ('dyu', iou, jmt, ib, ic, dyudeg, c1, c0)
+      call getvara ('yt', iou, jmt, ib, ic, yt, c1, c0)
+      call getvara ('yu', iou, jmt, ib, ic, yu, c1, c0)
+      ic(1) = km
+      call getvara ('dzt', iou, km, ib, ic, dzt, c100, c0)
+      call getvara ('dzw', iou, km, ib, ic, dzw(1:km), c100, c0)
+      call getvara ('zt', iou, km, ib, ic, zt, c100, c0)
+      call getvara ('zw', iou, km, ib, ic, zw, c100, c0)
       call closefile (iou)
+
+      if (zt(km) .gt. 8000.e2) then
+!       assume depths are in cm
+        print*, "==> Warning: converting depths to cm in gcoord"
+        zt(1:km) = zt(1:km)/100.
+        dzt(1:km) = dzt(1:km)/100.
+        zw(1:km) = zw(1:km)/100.
+        dzw(1:km) = dzw(1:km)/100.
+      endif
       dzw(0)  = zt(1)
       dzw(km) = zw(km) - zt(km)
 
@@ -412,7 +448,7 @@
 !     deltau = resolution of "u" grid cells: n=1,num
 !     deltat = resolution of "t" grid cells: n=1,num
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       include "stdunits.h"
@@ -561,7 +597,7 @@
 !     set up a staggered "B" grid for MOM and compute grid related
 !     variables
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       include "param.h"
@@ -575,6 +611,9 @@
       include "hmixc.h"
       include "vmixc.h"
 
+      integer ib(10), ic(10)
+      character(120) :: fname, new_file_name
+
 !-----------------------------------------------------------------------
 !     set some constants
 !-----------------------------------------------------------------------
@@ -639,6 +678,9 @@
 
       do k=1,km
 
+        dztur(k) = c1/(dzw(k-1)*dzt(k))
+        dztlr(k) = c1/(dzw(k)*dzt(k))
+
         dztr(k)  = c1/dzt(k)
       enddo
 
@@ -650,10 +692,8 @@
         dyur(jrow)  = c1/dyu(jrow)
         dyu2r(jrow) = p5/dyu(jrow)
         dyu4r(jrow) = p25/dyu(jrow)
-
         phi(jrow)   = yu(jrow)/radian
         phit(jrow)  = yt(jrow)/radian
-
         cst(jrow)   = cos(phit(jrow))
         csu(jrow)   = cos(phi (jrow))
         sine(jrow)  = sin(phi(jrow))
@@ -724,6 +764,17 @@
       enddo
       dzwxcl(km) = c0
 
+      fname = new_file_name ("grid.nc")
+      ib(:) = 1
+      ic(:) = imt
+      ic(2) = jmt
+      call openfile (fname, iou)
+      call getvara ('lat_t', iou, imt*jmt, ib, ic, tlat, c1, c0)
+      call getvara ('lon_t', iou, imt*jmt, ib, ic, tlon, c1, c0)
+      call getvara ('lat_u', iou, imt*jmt, ib, ic, ulat, c1, c0)
+      call getvara ('lon_u', iou, imt*jmt, ib, ic, ulon, c1, c0)
+      call closefile (iou)
+
       return
       end
 
