@@ -1,22 +1,23 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/embm/setembm.F
+! source file: /usr/local/models/UVic_ESCM/2.7/source/embm/setembm.F
       subroutine setembm
 
 !=======================================================================
 !     initialize the energy-moisture balance model
-!     based on code by a.fanning
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: A. Fanning and M. Eby
 !=======================================================================
 
       implicit none
 
       include "param.h"
+      include "calendar.h"
       include "solve.h"
       include "switch.h"
       include "coord.h"
       include "grdvar.h"
-      include "atm.h"
       include "cembm.h"
+      include "atm.h"
+      include "insolation.h"
 
       include "ice.h"
 
@@ -25,28 +26,41 @@
       include "riv.h"
       include "tmngr.h"
       include "levind.h"
-      include "mapsbc.h"
       include "csbc.h"
       include "scalar.h"
+      include "veg.h"
 
-      integer i, ie, ii, iou, is, j, je, jj, js, jz, k, m, n, nsolve, nu
-      integer nsum, ntrec
+      real rveg(imt,jmt)
 
-      real astl, asul, ctl, dn_s(nat), de_s(nat), dlam, dphi, dtatms
-      real dte, dyz, eccice, esatm_s, grarea, saltmax, si, solins_s
-      real stl, sul, t1, time, tlat_s, ulat_s, yz_max, yz_min, wz, zrel
+      character(120) :: fname, new_file_name
+      character(3) :: a3
+
+      integer i, ie, ii, iou, is, j, je, jj, js, jz, k, m, n, nsolve
+      integer nu, nsum, iice, ib(10), ic(10)
+
+      logical exists, inqvardef
+
+      real dlam, dphi, dtatms, dte, dyz, eccice, grarea, rhair, saltmax
+      real si, ssh, t1, tair, yz_max, yz_min, wz, calday
+      real zrel, C2K, c100
 
       namelist /tsteps/ dtts, dtuv, dtsf, dtatm, dtatms, namix, segtim
-      namelist /co2/    co2ccn, co2yri, co2yrf, co2rate, co2for
-      namelist /paleo/  pyear
-      namelist /ice/    niats, nivts, dampice, tsno, hsno_max
+      namelist /co2/    co2ccn, co2yri, co2yrf, co2rate, co2for, co2_yr
+      namelist /paleo/  orbit_yr, pyear, eccen, obliq, mvelp
+      namelist /ice/    niats, nivts, dampice, tsno, hsno_max, ice_yr
       namelist /adv_q/  diffactor
+      namelist /veg/    veg_alb, veg_rl, veg_rs, veg_smd, crops_yr
+     &,                 icrops, idesert, iice
+      namelist /solar/  solarconst, solar_yr
 
       is = 1
       ie = imt
       js = 1
       je = jmt
 
+      c100 = 100.
+      C2K = 273.15
+
 !-----------------------------------------------------------------------
 !     define default parameters
 !-----------------------------------------------------------------------
@@ -57,9 +71,15 @@
       co2yrf     = 1.e20
       co2rate    = 0.
       co2for     = 5.77e03
+      co2_yr     = 2.e20
 
 !     set defaults namelist paleo
-      pyear      = 0.
+      pyear      = 2.e20
+      orbit_yr   = 2.e20
+!     default user orbit is for 1950
+      eccen      = 1.672393E-02
+      obliq      = 23.44627
+      mvelp      = 102.0391
 
 !     set defaults namelist ice
       niats      = 1
@@ -68,21 +88,42 @@
       tsno       = -5.
       hsno_max   = 1000.
 
+      ice_yr     = 2.e20
+
 !     set defaults namelist adv_q
       diffactor  = 50.
 
-!     set other stuff
+!     set defaults namelist veg
+      veg_alb(1:4) = (/0.134054, 0.108081, 0.174938, 0.169483/)
+      veg_alb(5:7) = (/0.199028, 0.282249, 0.142956/)
+      veg_rl(1:4) = (/2.85857, 0.907664, 0.108264, 0.0529845/)
+      veg_rl(5:7) = (/0.0394621, 0.0389969, 0.0200000/)
+      veg_rs(1:7) = (/0.75, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0/)
+      veg_smd(1:7) = (/10.0, 10.0, 1.0, 0.1, 0.1, 0.01, 0.01/)
+      crops_yr = 2.e20
+      icrops = 3
+      idesert = 6
+      iice = 7
+
+!     set defaults namelist solar
       solarconst = 1.368e6
+      solar_yr = 2.e20
+
+!     set other stuff
       scatter    = 0.30
       pass       = 1. - scatter
 
-      ssp        = 1.e6
       cdatm      = 1.e-3
       cpatm      = 1.004e7
-      ht         = 8.4e5
-      hq         = 1.8e5
+      sht        = 8.4e5
+      shq        = 1.8e5
+      shc        = 7.9e5
       rhoatm     = 1.250e-3
-      rlapse     = 6.5e-5
+      esatm      = 4.7e-05
+      rlapse     = 6.e-5
+      rfactor    = 0.05
+      pcfactor   = 0.
+      cssh       = 3.8011e-3
 
       rhoocn     = 1.035
       esocn      = 5.347e-5
@@ -100,8 +141,8 @@
       soilmax    = 15.
       eslnd      = 5.347e-5
       cs_alb     = 0.08
-      ice_calb   = 0.45
-      sno_calb   = 0.35
+      ice_calb   = 0.4
+      sno_calb   = 0.4
 
       nivc       = 1
       dtatms     = 1800.
@@ -138,6 +179,20 @@
       write (stdout,adv_q)
       call relunit (iou)
 
+      call getunit (iou, 'control.in', 'f s r')
+      read  (iou, veg, end=106)
+106   continue
+      write (stdout,veg)
+      call relunit (iou)
+
+!     sort out forcing years
+      if (pyear  .gt. 1.e20) pyear = 2000.
+      if (orbit_yr .gt. 1.e20) orbit_yr = pyear
+      if (crops_yr .gt. 1.e20) crops_yr = pyear
+      if (ice_yr .gt. 1.e20) ice_yr = pyear
+      if (solar_yr .gt. 1.e20) solar_yr = pyear
+      if (co2_yr .gt. 1.e20) co2_yr = pyear
+
       if (mod(timavgint, segtim) .gt. 1.e-6 .and. timavgint .gt. 0.)
      &  then
         t1 = nint(timavgint/segtim)*segtim
@@ -189,91 +244,58 @@
 !     the year of the initial conditions
 !-----------------------------------------------------------------------
 
-      call berger (pyear)
+      call orbit (orbit_yr, eccen, obliq, mvelp, lambm0)
 
 !-----------------------------------------------------------------------
-!     calculate latitude dependent variables
+!     calculate annual average insolation and Coriolis factor
 !-----------------------------------------------------------------------
 
       radian = 360./(2.*pi)
-
       do j=1,jmt
-!-----------------------------------------------------------------------
-!       calculate coriolis parameter
-!-----------------------------------------------------------------------
 
-        fcor(j) = 2.*omega*sine(j)
-        tlat_s = yt(j)
-        stl = sin(yt(j)/radian)
-        ctl = cos(yt(j)/radian)
-        ulat_s = yu(j)
-        sul = sin(yu(j)/radian)
-
-          astl = abs(stl)
-          asul = abs(sul)
-
-!-----------------------------------------------------------------------
-!         calculate annual average insolation
-!-----------------------------------------------------------------------
-
-          solins_s = 0.
-          do n=1, 365
-            call insolation (float(n), tlat_s, si)
-            solins_s = solins_s + si
-          enddo
-          solins_s = (solins_s + 0.25*si) /365.25
-
-!-----------------------------------------------------------------------
-!         planetary and atmospheric emissivity
-!-----------------------------------------------------------------------
-
-          esatm_s = 5.57e-5*(0.8666 + 0.0408*stl - 0.2553*stl**2
-     &               - 0.4660*stl**3 + 0.9877*stl**4 + 2.0257*stl**5
-     &               - 2.3374*stl**6 - 3.1990*stl**7 + 2.8581*stl**8
-     &               + 1.6070*stl**9 -1.2685*stl**10)
-
-!-----------------------------------------------------------------------
-!         diffusivities
-!-----------------------------------------------------------------------
-
-          do n=1,nat
-
-            if (n .eq. 1) then
-              dn_s(1) = 3.e10*(1.3 - 1.1*asul**2 + .15*sul)
-              de_s(1) = 3.e10*(1.3 - 1.1*astl**2 + .15*stl)
-            endif
-            if (n .eq. 2) then
-              dn_s(2) = 1.e10
-              de_s(2) = 1.e10
-            endif
-
-            if (n .ge. 3) then
-              dn_s(n) = 1.e10
-              de_s(n) = 1.e10
-            endif
-          enddo
-
-!-----------------------------------------------------------------------
-!         load grid latitude dependent arrays
-!-----------------------------------------------------------------------
-
-        solins(j) = solins_s
-        esatm(j) = esatm_s
-
-        do n=1,nat
-          dn(j,n) = dn_s(n)
-          de(j,n) = de_s(n)
+        do i=1,imt
+!         calculate coriolis parameter
+          fcor(i,j) = 2.*omega*sin(ulat(i,j)/radian)
         enddo
-
       enddo
 
+!-----------------------------------------------------------------------
+!     read diffusion
+!-----------------------------------------------------------------------
+
+      dn(:,:,:) = 1.e10
+      de(:,:,:) = 1.e10
+      fname = new_file_name ("diff.nc")
+      inquire (file=trim(fname), exist=exists)
+      if (.not. exists) then
+        print*, "Warning => ", trim(fname), " does not exist."
+      else
+        call openfile (fname, iou)
+        ib(:) = 1
+        ic(:) = imt
+        ic(2) = jmt
+        do n=1,nat
+          if (n .lt. 1000) write(a3,'(i3)') n
+          if (n .lt. 100) write(a3,'(i2)') n
+          if (n .lt. 10) write(a3,'(i1)') n
+          call getvara ('dn_'//trim(a3), iou, imt*jmt, ib, ic, dn(1,1,n)
+     &,     c1, c0)
+          call getvara ('de_'//trim(a3), iou, imt*jmt, ib, ic, de(1,1,n)
+     &,     c1, c0)
+        enddo
+        call closefile (iou)
+      endif
+
+!-----------------------------------------------------------------------
 !     set solver parameters
+!-----------------------------------------------------------------------
 
       nsolve = 0
 
-      itin(1:nat)  = 100        ! max solver iterations
-      epsin(1) = 1.e-4         ! solver tolerance
-      epsin(2:nat) = 1.0e-11    ! solver tolerance
+      itin(1:nat)  = 500        ! max solver iterations
+
+      epsin(1) = 1.e-3
+      epsin(2:nat) = 1.e-10
 
       nsolve = nsolve + 1
 
@@ -281,7 +303,7 @@
         write(*,*) '==> Error: more or less than one solver defined.'
         write(*,*) '           Use only one of uvic_embm_adi,'
      &,   ' uvic_embm_mgrid, uvic_embm_slap, uvic_embm_essl or'
-     &,   ' uvic_embm_explicit'
+     &,   ' or uvic_embm_sparskit or uvic_embm_explicit'
         stop '=>setembm'
       endif
 
@@ -293,12 +315,6 @@
      &   '==> Warning: changing latent heat of fusion to conserve heat'
         flice = slice - vlocn
 
-!-----------------------------------------------------------------------
-!     initialize the river model
-!-----------------------------------------------------------------------
-
-      call rivinit
-
 !-----------------------------------------------------------------------
 !     calculate grid terms for the atmospheric solver
 !-----------------------------------------------------------------------
@@ -319,18 +335,40 @@
       enddo
 
 !-----------------------------------------------------------------------
-!     set surface coalbedo to zero
+!     read constant annual average snow-free surface albedos
 !-----------------------------------------------------------------------
 
+!     read surface albedo
+      sbc(:,:,icalb) = c0
+      fname = new_file_name ("sf_alb_ann.nc")
+      inquire (file=trim(fname), exist=exists)
+      if (.not. exists) then
+        print*, "Warning => ", trim(fname), " does not exist."
+      else
+        ib(:) = 1
+        ic(:) = imt
+        ic(2) = jmt
+        call openfile (fname, iou)
+        call getvara ('sf_alb', iou, imt*jmt, ib, ic, sbc(1,1,icalb)
+     &,   c1, c0)
+        call closefile (iou)
+      endif
+
+!     calculate new grid yz for zonal averages
+      yz_max = -90.
+      yz_min = 90.
       do j=1,jmt
         do i=1,imt
-          s_calb(i,j) = 0.
+          yz_max = max(yz_max, tlat(i,j))
+          yz_min = min(yz_min, tlat(i,j))
         enddo
       enddo
-      pcfactor = 0.
-
-      do jz=1,jmt
-
+      dyz = (yz_max-yz_min)/float(jmz-3)
+      yz_max = yz_max + dyz
+      yz_min = yz_min - dyz
+      dyz = (yz_max-yz_min)/float(jmzm1)
+      do jz=1,jmz
+        yz(jz) = yz_min + float(jz-1)*dyz
         area_z(jz) = epsln
         s_alb_z(jz) = 0.
       enddo
@@ -338,24 +376,32 @@
 !     convert to coalbedo and find weights for zonal averaging
       do j=1,jmt
         do i=1,imt
-          s_calb(i,j) = c1 - s_calb(i,j)
-
+          sbc(i,j,icalb) = c1 - sbc(i,j,icalb)
+          do jz=1,jmzm1
+            if (tlat(i,j).ge.yz(jz) .and. tlat(i,j).le.yz(jz+1)) then
+              wt_zonal(i,j) = jz + (yz(jz)-tlat(i,j))/(yz(jz)-yz(jz+1))
+            endif
+          enddo
        enddo
       enddo
 
-!     calculate zonal average snow free albedo. s_calb may then be
-!     changed but the constant zonal average, s_alb_z should not.
+!     calculate zonal average snow free albedo. sbc(:,:,icalb) may then
+!     be changed but the constant zonal average, s_alb_z should not.
       do j=2,jmtm1
         do i=2,imtm1
           grarea = dxt(i)*dyt(j)*cst(j)
-
-          area_z(j) = area_z(j) + grarea
-          s_alb_z(j) = s_alb_z(j) + s_calb(i,j)*grarea
+          jz = int(wt_zonal(i,j))
+          wz = wt_zonal(i,j) - jz
+          area_z(jz) = area_z(jz) + (c1-wz)*grarea
+          area_z(jz+1) = area_z(jz+1) + wz*grarea
+          s_alb_z(jz) = s_alb_z(jz) + (c1-wz)*sbc(i,j,icalb)*grarea
+          s_alb_z(jz+1) = s_alb_z(jz+1) + wz*sbc(i,j,icalb)*grarea
         enddo
-!       ensure zonal surface albedo is between zero and one.
-        s_alb_z(j) = c1 - min(max(s_alb_z(j)/area_z(j), 0.), c1)
       enddo
-
+      do jz=1,jmz
+!       ensure zonal surface albedo is between zero and one.
+        s_alb_z(jz) = c1 - min(max(s_alb_z(jz)/area_z(jz), c0), c1)
+      enddo
 !     ensure pass is between zero and one.
       pass = min(max(pass, epsln), c1-epsln)
 
@@ -365,49 +411,70 @@
 
       newcoef(:,:) = .true.
 
-      if (init) then
-        nats = namix
-        irstdy = 0
-        msrsdy = 0
-        at(:,:,:,:) = 0.
-        at(:,:,:,1) = 10.
-        at(:,:,:,2) = 0.01
+      nats = namix
+      dayoyr = 1.
+      itt = 0
+      irstdy = 0
+      msrsdy = 0
 
-        avgp(:,:) = 0.
+      at(:,:,:,:) = 0.
+      tair = 10.
+      rhair = 0.9
+      at(:,:,:,isat) = tair
+      ssh = cssh*exp(17.67*tair/(tair + 243.5))
+      rh(:,:) = rhair
+      at(:,:,:,ishum) = rhair*ssh
 
-        hice(:,:,1) = 0.
-        hice(:,:,2) = 0.
-        aice(:,:,1) = 0.
-        aice(:,:,2) = 0.
-        tice(:,:) = 0.
-        hsno(:,:,1) = 0.
-        hsno(:,:,2) = 0.
+      precip(:,:) = 0.
+      sbc(:,:,isst) = 0.
+      sbc(:,:,isss) = 0.
+      tmsk(:,:) = 0.
 
-        uice(:,:) = 0.
-        vice(:,:) = 0.
-        sig11n(:,:) = 0.
-        sig11e(:,:) = 0.
-        sig11s(:,:) = 0.
-        sig11w(:,:) = 0.
-        sig22n(:,:) = 0.
-        sig22e(:,:) = 0.
-        sig22s(:,:) = 0.
-        sig22w(:,:) = 0.
-        sig12n(:,:) = 0.
-        sig12e(:,:) = 0.
-        sig12s(:,:) = 0.
-        sig12w(:,:) = 0.
+      aicel(:,:,:) = 0.
+      hicel(:,:,:) = 0.
 
-        bv(:) = 0.
-        xv(:) = 0.
+      avgp(:,:) = 0.
+      accp(:,:) = 0.
 
-        raux(:) = 0.
-        iaux(:) = 0
+      soilm(:,:,:) = 0.
+      surf(:,:) = 0.
 
-      else
+      hice(:,:,:) = 0.
+      aice(:,:,:) = 0.
+      tice(:,:) = 0.
+      hsno(:,:,:) = 0.
 
-        call atm_rest_in ('restatm.nc', is, ie, js, je)
+      uice(:,:) = 0.
+      vice(:,:) = 0.
+      sbc(:,:,isu) = 0.
+      sbc(:,:,isv) = 0.
+      sbc(:,:,igu) = 0.
+      sbc(:,:,igv) = 0.
+      sig11n(:,:) = 0.
+      sig11e(:,:) = 0.
+      sig11s(:,:) = 0.
+      sig11w(:,:) = 0.
+      sig22n(:,:) = 0.
+      sig22e(:,:) = 0.
+      sig22s(:,:) = 0.
+      sig22w(:,:) = 0.
+      sig12n(:,:) = 0.
+      sig12e(:,:) = 0.
+      sig12s(:,:) = 0.
+      sig12w(:,:) = 0.
 
+      bv(:) = 0.
+      xv(:) = 0.
+
+      raux(:) = 0.
+      iaux(:) = 0
+
+      tmsk(:,:) = 0.
+      umsk(:,:) = 0.
+
+      if (.not. init) then
+        fname = new_file_name ("restart_embm.nc")
+        call embm_rest_in (fname, is, ie, js, je)
       endif
 
       flux(:,:,:) = 0.0
@@ -422,18 +489,21 @@
 !     read land elevations
 !-----------------------------------------------------------------------
 
-      time = 0.
-      ntrec = 1
-      call openfile ('data/elev.nc', time, ntrec, iou)
-      call getvara ('elev', iou, imt*jmt, (/1,1/)
-     &,            (/imt,jmt/), elev, 0.01, 0.)
-      call closefile (iou)
+      elev(:,:) = 0.
+      fname = new_file_name ("elev.nc")
+      inquire (file=trim(fname), exist=exists)
+      if (.not. exists) then
+        print*, "Warning => ", trim(fname), " does not exist."
+      else
+        ib(:) = 1
+        ic(:) = imt
+        ic(2) = jmt
+        call openfile (fname, iou)
+        call getvara ('elev', iou, imt*jmt, ib, ic, elev, c100, c0)
+        call closefile (iou)
+      endif
 !     check for negative elevations
-      do j=1,jmt
-        do i=1,imt
-          if (elev(i,j) .lt. 0.) elev(i,j) = 0.
-        enddo
-      enddo
+      where (elev(:,:) .lt. 0.) elev(:,:) = 0.
 
 !-----------------------------------------------------------------------
 !     calculate albedo
@@ -442,31 +512,125 @@
       call albedo
 
 !-----------------------------------------------------------------------
-!     calculate B grid ice masks
+!     set tracer grid ocean mask
 !-----------------------------------------------------------------------
 
+      fname = new_file_name ("restatm.nc")
+      inquire (file=trim(fname), exist=exists)
+      if (exists) then
+        call openfile (fname, iou)
+        exists = inqvardef('tmsk', iou)
+        call closefile (iou)
+      endif
+
+      if (.not. exists .or. init) then
+!       read tmsk if not in the restart or starting from initial condition
+        fname = new_file_name ("tmsk.nc")
+        inquire (file=trim(fname), exist=exists)
+        if (exists) then
+          call openfile (fname, iou)
+          exists = inqvardef('tmsk', iou)
+          if (exists) then
+            ib(:) = 1
+            ic(:) = imt
+            ic(2) = jmt
+            call getvara ('tmsk', iou, imt*jmt, ib, ic, tmsk, c1, c0)
+          endif
+          call closefile (iou)
+        endif
+        if (.not. exists) then
+!         if tmsk does not exist use kmt
+          tmsk(:,:) = 0.
+          do j=1,jmtm1
+            do i=1,imtm1
+              if (kmt(i,j) .gt. 0.) tmsk(i,j) = 1.
+            enddo
+          enddo
+        endif
+      endif
+
+!-----------------------------------------------------------------------
+!     set landice data
+!-----------------------------------------------------------------------
+
+      call icedata
+
       do j=1,jmtm1
         do i=1,imtm1
-          tm(i,j) = 0.
-          um(i,j) = 0.
-          if (kmt(i,j) .gt. 0) tm(i,j) = 1.
-          if (kmu(i,j) .gt. 0) um(i,j) = 1.
+          if (aicel(i,j,2) .ge. 0.5) tmsk(i,j) = 0.
         enddo
       enddo
-      call embmbc (tm)
-      call embmbc (um)
+
+      call embmbc (tmsk)
+
+!-----------------------------------------------------------------------
+!     set velocity grid ocean mask
+!-----------------------------------------------------------------------
+
+      do j=2,jmtm1
+        do i=2,imtm1
+          umsk(i,j) = min (tmsk(i,j), tmsk(i+1,j), tmsk(i,j+1)
+     &,                    tmsk(i+1,j+1))
+        enddo
+      enddo
+      call embmbc (umsk)
+!     remove isolated bays
+      do j=2,jmtm1
+        do i=2,imtm1
+          tmsk(i,j) = max (umsk(i,j), umsk(i-1,j), umsk(i,j-1)
+     &,                    umsk(i-1,j-1))
+        enddo
+      enddo
+      call embmbc (tmsk)
+
+!-----------------------------------------------------------------------
+!     read vegetation class
+!-----------------------------------------------------------------------
+
+      rveg(:,:) = 0.
+
+      fname = new_file_name ("veg_type.nc")
+
+      inquire (file=trim(fname), exist=exists)
+      if (.not. exists) then
+        print*, "Warning => ", trim(fname), " does not exist."
+      else
+        call openfile (fname, iou)
+        call getvara ('veg', iou, imt*jmt, ib, ic, rveg, c1, c0)
+        call closefile (iou)
+      endif
+      do j=1,jmt
+        do i=1,imt
+          if (kmt(i,j) .gt. 0) then
+            iveg(i,j) = iice
+          elseif (rveg(i,j) .gt. 0.6 .and. rveg(i,j) .lt. 7.4) then
+            iveg(i,j) = nint(rveg(i,j))
+          else
+            print*, "==> Error: invalid vegetation type, ", rveg(i,j)
+            print*, "           at point (i,j), ", i, j
+            stop 'veg check in setembm.f'
+          endif
+        enddo
+      enddo
+
+      call gvsbc
+
+!-----------------------------------------------------------------------
+!     set the river model
+!-----------------------------------------------------------------------
+
+      call rivinit
+
+!----------------------------------------------------------------------
+!     initialize elastic viscous plastic variables
+!-----------------------------------------------------------------------
 
       dlam = dxu(int(imt/2))/100.
       dphi = dyu(int(jmt/2))/100.
       diff1 = 0.004
       diff1 = diff1*dlam
       diff2 = diff1*dlam**2
-
-!----------------------------------------------------------------------
-!     initialize elastic viscous plastic variables
-!-----------------------------------------------------------------------
-
-      eccice = 10.
+      eccice = 2.
       ecc2 = 1./(eccice**2)
       ecc2m = 2.*(1.-ecc2)
       ecc2p = (1.+ecc2)
@@ -485,15 +649,24 @@
 !     check for even flux averaging
 !-----------------------------------------------------------------------
 
-      if (mod(namix,2) .ne. mod(nint(segtim*86400./dtatm),2)) then
+      if (mod(namix,2) .ne. mod(nint(segtim*daylen/dtatm),2)) then
         write(*,*) '==> Error: time steps between mixing and coupling'
-     &, ' must both be even to use uvic_embm_even_fluxes.'
+        write(*,*) '           in the atmosphere must both be even to'
+        write(*,*) '           use uvic_embm_even_fluxes.'
+        stop '=>setembm'
+      endif
+
+      if (mod(nmix,2) .ne. mod(nint(segtim*daylen/dtocn),2)) then
+        write(*,*) '==> Error: time steps between mixing and coupling'
+        write(*,*) '           in the ocean must both be even to use'
+        write(*,*) '           uvic_embm_even_fluxes.'
         stop '=>setembm'
       endif
 
       if (mod(namix,2) .ne. mod(nats,2)) then
         write(*,*) '==> Warning: restart was not saved with even flux'
-     &, ' averaging. Starting with a mixing time step.'
+        write(*,*) '             averaging. Starting with a mixing time'
+        write(*,*) '             step.'
         nats = namix
       endif
 
@@ -501,23 +674,23 @@
 !     check ice velocity calculation
 !-----------------------------------------------------------------------
 
-      if (nivts .gt. nint(segtim*86400./dtatm)) then
-        write(*,*) '==> Warning: ice velocities will be calculated '
-     &, 'every coupling time.'
-        nivts =  nint(segtim*86400./dtatm)
+      if (nivts .gt. nint(segtim*daylen/dtatm)) then
+        write(*,*) '==> Warning: ice velocities will be calculated'
+        write(*,*) '             every coupling time.'
+        nivts =  nint(segtim*daylen/dtatm)
       endif
 
 !-----------------------------------------------------------------------
 !     zero time average accumulators
 !-----------------------------------------------------------------------
 
-      call ta_atm_snap (is, ie, js, je, 0)
+      call ta_embm_snap (is, ie, js, je, 0)
 
 !-----------------------------------------------------------------------
 !     zero integrated time average accumulators
 !-----------------------------------------------------------------------
 
-      call ta_atm_tsi (0)
+      call ta_embm_tsi (0)
 
       return
       end
