@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/tbt.h
+! source file: /usr/local/models/UVic_ESCM/2.7/source/mom/tbt.h
 !====================== include file "tbt.h" ===========================
 
 !     ntbtts = number of tracer term balance time steps
