@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/mom/termbal.F
+! source file: /usr/local/models/UVic_ESCM/2.7/source/mom/termbal.F
       subroutine utb1 (joff, js, je, is, ie, n)
 
 !=======================================================================
@@ -13,7 +13,7 @@
 !       ie   = ending longitude index in the MW
 !       n    = velocity component
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       include "param.h"
@@ -203,7 +203,7 @@
 !       c2dtuv = (2*dtuv,dtuv) on (lpfrod,mixing) time steps
 !       acor   = implicit factor
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       include "param.h"
@@ -245,9 +245,7 @@
 !-----------------------------------------------------------------------
 
                 if (acor .ne. c0) then
-
-                  term = umask(i,k,j)*acor*cori(jrow,n)*
-
+                  term = umask(i,k,j)*acor*cori(i,jrow,n)*
      &                       (u(i,k,j,3-n,taup1) - u(i,k,j,3-n,taum1))
                   call addto (termbm(k,10,n,nreg), term*boxvol)
                 endif
@@ -267,7 +265,7 @@
 !     term and the surface pressure gradientsover the volume in the
 !     specified regions.
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       include "param.h"
@@ -284,11 +282,9 @@
       do jrow=1,jmt-1
         fddt  = csu(jrow)*dyu(jrow)/c2dtuv
         fspr  = csu(jrow)*dyu(jrow)
-
-        atosp = acor*cori(jrow,1)
-        f1    = atosp*csu(jrow)*dyu(jrow)
         do i=2,imtm1
-
+          atosp = acor*cori(i,jrow,1)
+          f1    = atosp*csu(jrow)*dyu(jrow)
           kz = kmu(i,jrow)
           if (kz .ne. 0) then
             do k=1,kz
@@ -334,7 +330,7 @@
 !       ie    = ending longitude index in the MW
 !       n     = tracer component
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       include "param.h"
@@ -345,6 +341,8 @@
       include "grdvar.h"
       include "hmixc.h"
 
+      include "isopyc.h"
+
       include "mw.h"
       include "scalar.h"
       include "vmixc.h"
@@ -482,6 +480,8 @@
 
               term = tmask(i,k,j)*DIFF_Tz(i,k,j)
 
+     &               + tmask(i,k,j)*zzi(i,k,j)
+
               call addto (termbt(k,7,n,nreg), term*boxvol)
               call addto (termbt(k,7,n,0),    term*boxvol)
 
@@ -534,7 +534,7 @@
 !     iterm = 1  => total change
 !     iterm = 10 => change due to filtering
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: R. C. Pacanowski
 !=======================================================================
 
       include "param.h"
