@@ -1,4 +1,4 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/util.F
+! source file: /usr/local/models/UVic_ESCM/2.7/source/common/util.F
       function indp (value, array, ia)
 
 !=======================================================================
@@ -23,7 +23,7 @@
 !                   program, then the returned index should be reduced
 !                   by one to account for the zero base.
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: P. C. Pacanowski
 
 !     example:
 
@@ -129,7 +129,7 @@
 !     yc(jstart)...yc(jend) must be within yf(1)...yf(jf). all
 !     coordinates must be strictly monotonically increasing.
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: P. C. Pacanowski
 !=======================================================================
 
       include "stdunits.h"
@@ -479,7 +479,7 @@
 !     and yc(js)...yc(je) must be within yf(1)...yf(jf). all coordinates
 !     must be strictly monotonically increasing.
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: P. C. Pacanowski
 !=======================================================================
 
       include "stdunits.h"
@@ -685,7 +685,7 @@
 !     a       = array with extrapolated values in land areas.
 !               non land areas remain unchanged.
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: P. C. Pacanowski
 !=======================================================================
 
       logical done
@@ -821,7 +821,7 @@
 !=======================================================================
 !      map integer array "iarray" into characters for printing with
 !      format (a1) to provide a contour map of the integer field.
-!      note: max number of unique characters = 80
+!      note: max number of unique characters = 120
 
 !     inputs:
 
@@ -832,12 +832,12 @@
 
 !     output: prints contour map of "iarray"
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: P. C. Pacanowski
 !=======================================================================
 
       include "stdunits.h"
       dimension iarray(im,jl)
-      character(80) :: levels, lev1
+      character(120) :: levels, lev1
       save levels
       write (stdout,*) ' '
 
@@ -880,7 +880,7 @@
         write (stdout,*)
      & ' => Note: there are ',maxint-minint+1,' integers in the field'
         write (stdout,*) '          "iplot" cannot uniquely assign '
-     &,' more than 80 characters for plotting symbols.'
+     &,' more than 120 characters for plotting symbols.'
         write (stdout,*) '          therfore integers are'
      &, ' represented by cyclicly reusing the list of plotting symbols'
         write (stdout,*) '   '
@@ -928,7 +928,7 @@
 
 !     output: print integer "iarray" with user format control
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: P. C. Pacanowski
 !=======================================================================
 
       include "stdunits.h"
@@ -1110,7 +1110,7 @@
 
 !     output: prints min, max (with locations), and average of "array"
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: P. C. Pacanowski
 !=======================================================================
 
       character(*) :: text
@@ -1157,7 +1157,7 @@
 
 !     output: sums the first index of array "a" for each 2nd index
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: P. C. Pacanowski
 !=======================================================================
 
       character(*) :: text
@@ -1219,7 +1219,7 @@
 
 !     output: contours "array"
 
-!     author:      r. c. pacanowski      e-mail=> rcp@gfdl.gov
+!     based on code by: P. C. Pacanowski
 !=======================================================================
 
       parameter (maxbin=52, ncols=124)
@@ -1439,78 +1439,63 @@
 998   format (1x,a4,(5x,10e11.4))
       end
 
-      subroutine areatot (data, land, tot)
+      subroutine areatot (data, dmsk, tot)
 
 !=======================================================================
 !     calculate the area weighted total of data
-!     based on code by a.fanning
 
 !     input:
 !       data = data to be totaled
-!       land = flag for land (0=ocean only 1=land+ocean 2=land only)
+!       dmsk = data mask
 !     output:
 !       tot = area weighted total of the data
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by A. Fanning and M. Eby
 !=======================================================================
 
+      implicit none
+
       include "param.h"
       include "grdvar.h"
-      include "levind.h"
+      include "atm.h"
 
-      real data(imt,jmt)
+      integer i, j, land
+      real sl, el, fx, tot, data(imt,jmt), dmsk(imt,jmt)
 
       tot = 0.0
 
-      if (land .eq. 2) then
-        do j=2,jmtm1
-          fx = cst(j)*dyt(j)
-          do i=2,imtm1
-            if (kmt(i,j) .eq. 0) then
-              tot = tot + data(i,j)*dxt(i)*fx
-            endif
-          enddo
+      do j=2,jmtm1
+        fx = cst(j)*dyt(j)
+        do i=2,imtm1
+          tot = tot + data(i,j)*dxt(i)*fx*dmsk(i,j)
         enddo
-      elseif (land .eq. 1) then
-        do j=2,jmtm1
-          fx = cst(j)*dyt(j)
-          do i=2,imtm1
-            tot = tot + data(i,j)*dxt(i)*fx
-          enddo
-        enddo
-      else
-       do j=2,jmtm1
-         fx = cst(j)*dyt(j)
-         do i=2,imtm1
-           if (kmt(i,j) .gt. 0) then
-             tot = tot + data(i,j)*dxt(i)*fx
-           endif
-         enddo
-       enddo
-      endif
+      enddo
 
       return
       end
 
-      subroutine areaavg (data, land, avg)
+      subroutine areaavg (data, dmsk, avg)
+
 !=======================================================================
 !     calculate the area weighted average of data
-!     based on code by a.fanning
 
 !     input:
 !       data = data to be averaged
-!       land = flag for land (0=exclude 1=include)
+!       dmsk = data mask
 !     output:
 !       avg = area weighted average of the data
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by A. Fanning and M. Eby
 !=======================================================================
 
+      implicit none
+
       include "param.h"
       include "grdvar.h"
-      include "levind.h"
+      include "atm.h"
 
-      real data(imt,jmt)
+      integer i, j
+      real fx, tarea, tdata, area, avg, data(imt,jmt), dmsk(imt,jmt)
 
       tarea = 0.0
       tdata = 0.0
@@ -1519,55 +1504,14 @@
       do j=2,jmtm1
         fx = cst(j)*dyt(j)
         do i=2,imtm1
-          if (kmt(i,j) + land  .gt. 0) then
-            area = dxt(i)*fx
-            tarea = tarea + area
-            tdata = tdata + data(i,j)*area
-          endif
+          area = dxt(i)*fx*dmsk(i,j)
+          tarea = tarea + area
+          tdata = tdata + data(i,j)*area
         enddo
       enddo
+
       if (tarea .ne. 0.0) avg = tdata/tarea
 
       return
       end
 
-      subroutine zonal (data, land, zavg)
-
-!=======================================================================
-!     calculate the zonal area integral of data
-!     based on code by a.fanning
-
-!     input:
-!       data = data to be averaged
-!       land = flag for land (0=exclude 1=include)
-!     output:
-!       zavg = zonal average
-
-!     author:   m.eby   e-mail: eby@uvic.ca
-!=======================================================================
-
-      include "param.h"
-      include "grdvar.h"
-      include "levind.h"
-
-      real data(imt,jmt), zavg(jmt)
-
-      do j=2,jmtm1
-        tarea = 0.0
-        tdata = 0.0
-        area = 0.0
-        zavg(j) = 0.0
-        fx = cst(j)*dyt(j)
-        do i=2,imtm1
-          if (kmt(i,j) + land .gt. 0) then
-            area = dxt(i)*fx
-            tdata = tdata + data(i,j)*area
-            tarea = tarea + area
-          endif
-        enddo
-        if (tarea .ne. 0.0) zavg(j) = tdata/tarea
-      enddo
-
-      return
-      end
-
