@@ -1,65 +1,191 @@
-! source file: /den/eby/UVic_ESCM/2.6/source/common/uvic_netcdf.F
-      subroutine openfile (fname, relyr, ntrec, ncid)
+      subroutine opentime (fname, relyr, ntrec, ncid)
 !=======================================================================
-!     open file for reading or writing
+!     open file for reading or writing at record of relyr
 
 !     input:
 !       fname = file name to be opened
 !       relyr = relative year
-!       ntrec = number of time record (clobber if set less than 0)
 !     output:
-!       ntrec = number of time record
+!       ntrec = rexcord number of relyr (next if relyr is not found)
 !       ncid  = iou unit
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: fname
-      character(80) :: name
+      character(*), intent(in) :: fname
+      character(120) :: name
 
-      integer i, id, iv, ln, n, ncid, ntrec
+      integer, intent(out) :: ncid, ntrec
+      integer i, id, iv, ln, n
 
-      real relyr
+      real, intent(in) :: relyr
       real(kind=8), allocatable :: time(:)
 
       logical exists
 
       name = fname
       inquire (file=trim(name), exist=exists)
-      if ( ntrec .lt. 0. ) exists = .false.
-      ntrec = 1
       if (.not. exists) then
-        i = nf_create (trim(name), nf_clobber, ncid)
-        call checkerror (i,'openfile '//trim(name))
-        i = nf_enddef (ncid)
-        call checkerror (i,'openfile nf_enddef')
-        ntrec = 0
-      else
-        i = nf_open (trim(name), nf_write, ncid)
-        call checkerror (i,'openfile nf_open '//trim(name))
-        i = nf_inq_varid (ncid, 'time', iv)
-        if (i .ne. nf_noerr) return
-        i = nf_inq_vardimid (ncid, iv, id)
-        if (i .ne. nf_noerr) return
-        i = nf_inq_dimlen (ncid, id, ln)
-        if (i .ne. nf_noerr) return
-        allocate (time(ln))
-        i = nf_get_var_double (ncid, iv, time)
-        if (i .ne. nf_noerr) then
-          deallocate (time)
-          return
-        endif
-!       find correct the record number for this time (within 32 sec)
-        ntrec = ln + 1
-        do n=1,ln
-           if (abs(time(n) - relyr) .lt. 1.e-6) ntrec = n
-        enddo
-        deallocate (time)
+        call opennew (name, ncid)
+        return
       endif
+      ntrec = 0
+      i = nf_open (trim(name), nf_write, ncid)
+      if (i .ne. nf_noerr) then
+        i = nf_open (trim(name), nf_nowrite, ncid)
+      endif
+      call checkerror (i,'opentime nf_open '//trim(name))
+      i = nf_inq_varid (ncid, 'time', iv)
+!     return if no time variable
+      if (i .ne. nf_noerr) return
+      i = nf_inq_vardimid (ncid, iv, id)
+      call checkerror (i,'opentime  nf_inq_vardimid'//trim(name))
+      i = nf_inq_dimlen (ncid, id, ln)
+      call checkerror (i,'opentime  nf_inq_dimlen'//trim(name))
+      allocate (time(ln))
+!     find ntrec of relyr or next if relyr is not found
+      i = nf_get_var_double (ncid, iv, time)
+      call checkerror (i,'opentime nf_get_vara_double time')
+      ntrec = ln + 1
+      do n=1,ln
+       if (abs(time(n) - relyr) .lt. 1.e-6) ntrec = n
+      enddo
+      deallocate (time)
+
+      return
+      end
+
+      subroutine opennext (fname, relyr, ntrec, ncid)
+!=======================================================================
+!     open file for reading or writing at next record number
+
+!     input:
+!       fname = file name to be opened
+!       relyr = relative year
+!     output:
+!       ntrec = next record number (or last if last is relyr)
+!       ncid  = iou unit
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      include 'netcdf.inc'
+
+      character(*), intent(in) :: fname
+      character(120) :: name
+
+      integer, intent(out) :: ncid, ntrec
+      integer i, id, iv, ln, n
+
+      real, intent(in) :: relyr
+      real(kind=8) time
+
+      logical exists
+
+      name = fname
+      inquire (file=trim(name), exist=exists)
+      if (.not. exists) then
+        call opennew (name, ncid)
+        return
+      endif
+
+      ntrec = 0
+      i = nf_open (trim(name), nf_write, ncid)
+      if (i .ne. nf_noerr) then
+        i = nf_open (trim(name), nf_nowrite, ncid)
+      endif
+      call checkerror (i,'opennext nf_open '//trim(name))
+      i = nf_inq_varid (ncid, 'time', iv)
+!     return if no time variable
+      if (i .ne. nf_noerr) return
+      i = nf_inq_vardimid (ncid, iv, id)
+      call checkerror (i,'opennext  nf_inq_vardimid'//trim(name))
+      i = nf_inq_dimlen (ncid, id, ln)
+      call checkerror (i,'opennext  nf_inq_dimlen'//trim(name))
+!     get next record or last if last is relyr
+      i = nf_get_vara_double (ncid, iv, ln, 1, time)
+      call checkerror (i,'opennext nf_get_vara_double time')
+      ntrec = ln + 1
+      if (abs(time - relyr) .lt. 1.e-6) ntrec = ln
+
+      return
+      end
+
+      subroutine openfile (fname, ncid)
+!=======================================================================
+!     open file for reading or writing
+
+!     input:
+!       fname = file name to be opened
+!     output:
+!       ncid  = iou unit
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      include 'netcdf.inc'
+
+      character(*), intent(in) :: fname
+      character(120) :: name
+
+      integer, intent(out) :: ncid
+      integer i
+
+      logical exists
+
+      name = fname
+      inquire (file=trim(name), exist=exists)
+      if (.not. exists) then
+        call opennew (name, ncid)
+        return
+      endif
+
+      i = nf_open (trim(name), nf_write, ncid)
+      if (i .ne. nf_noerr) then
+        i = nf_open (trim(name), nf_nowrite, ncid)
+      endif
+      call checkerror (i,'openfile nf_open '//trim(name))
+
+      return
+      end
+
+      subroutine opennew (fname, ncid)
+!=======================================================================
+!     open file for reading or writing
+
+!     input:
+!       fname = file name to be opened
+!     output:
+!       ncid  = iou unit
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      include 'netcdf.inc'
+
+      character(*), intent(in) :: fname
+      character(120) :: name
+
+      integer, intent(out) :: ncid
+      integer i
+
+      logical exists
+
+      name = fname
+      i = nf_create (trim(name), nf_clobber, ncid)
+      call checkerror (i,'openfile '//trim(name))
+      i = nf_enddef (ncid)
+      call checkerror (i,'openfile nf_enddef')
 
       return
       end
@@ -71,14 +197,15 @@
 !     input:
 !       ncid = iou unit
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      integer i, ncid
+      integer, intent(in) :: ncid
+      integer i
 
       i = nf_close (ncid)
       call checkerror (i,'closefile nf_close')
@@ -93,14 +220,15 @@
 !     input:
 !       ncid = iou unit
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      integer i, ncid
+      integer, intent(in) :: ncid
+      integer i
 
       i = nf_redef(ncid)
       call checkerror (i,'redef nf_redef')
@@ -115,14 +243,15 @@
 !     input:
 !       ncid = iou unit
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      integer i, ncid
+      integer, intent(in) :: ncid
+      integer i
 
       i = nf_enddef (ncid)
       call checkerror (i,' enddef nf_enddef')
@@ -138,16 +267,16 @@
 !       i     = netcdf error index
 !       trace = trace string
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: trace
+      character(*), intent(in) :: trace
 
-      integer i
+      integer, intent(in) :: i
 
       if (i .ne. nf_noerr) then
         print*, 'netcdf error: ', nf_strerror(i)
@@ -163,21 +292,23 @@
 !     check if a variable is defined
 
 !     input:
-!       name       = variable name
-!       ncid       = iou unit
-
+!       name = variable name
+!       ncid = iou unit
 !     output:
 !        inqvardef = (true, false) = (defined, not defined)
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: name
-      integer i, iv, ncid
+      character(*), intent(in) :: name
+
+      integer, intent(in) :: ncid
+      integer i, iv
+
       logical inqvardef
 
       inqvardef = .false.
@@ -197,40 +328,46 @@
 !       title   = file title
 !       expnam  = experiment name
 !       timunit = timunit
-!       rlapse  = atmospheric lapse rate
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: name, title, expnam, timunit
+      character(*), intent(in) :: name, title, expnam, timunit
 
-      integer i, ncid, ntrec
+      integer, intent(in) :: ncid
+      integer i
 
-      real timper, rlapse
+      i = nf_put_att_text (ncid, nf_global, 'Conventions'                                                                             &
+     &, len('CF-1.0'), 'CF-1.0')
+      call checkerror(i,'putglobal conventions '//trim(name))
 
-      i = nf_put_att_text (ncid, nf_global, 'file_name'
-     &, len(trim(name)), trim(name))
-      call checkerror(i,'putglobal file_name '//trim(name))
+      if (len(trim(name)) .ne. 0) then
+        i = nf_put_att_text (ncid, nf_global, 'file_name'                                                                              &
+     &,   len(trim(name)), trim(name))
+        call checkerror(i,'putglobal file_name '//trim(name))
+      endif
 
-      i = nf_put_att_text (ncid, nf_global, 'title'
-     &, len(trim(title)), trim(title))
-      call checkerror (i,'putglobal title '//trim(name))
+      if (len(trim(title)) .ne. 0) then
+        i = nf_put_att_text (ncid, nf_global, 'title'                                                                                  &
+     &,   len(trim(title)), trim(title))
+        call checkerror (i,'putglobal title '//trim(name))
+      endif
 
-      i = nf_put_att_text (ncid, nf_global, 'convention'
-     &, len('COARDS'), 'COARDS')
-      call checkerror(i,'putglobal convention '//trim(name))
+      if (len(trim(expnam)) .ne. 0) then
+        i = nf_put_att_text (ncid, nf_global, 'experiment_name'                                                                        &
+     &,   len(trim(expnam)), trim(expnam))
+        call checkerror (i,'putglobal experiment_name '//trim(name))
+      endif
 
-      i = nf_put_att_text (ncid, nf_global, 'experiment_name'
-     &, len(trim(expnam)), trim(expnam))
-      call checkerror (i,'putglobal experiment_name '//trim(name))
-
-      i = nf_put_att_text (ncid, nf_global, 'time_unit'
-     &, len(trim(timunit)), trim(timunit))
-      call checkerror (i,'putglobal time_unit '//trim(name))
+      if (len(trim(timunit)) .ne. 0) then
+        i = nf_put_att_text (ncid, nf_global, 'time_unit'                                                                              &
+     &,   len(trim(timunit)), trim(timunit))
+        call checkerror (i,'putglobal time_unit '//trim(name))
+      endif
 
       return
       end
@@ -241,27 +378,23 @@
 
 !     input:
 !       ncid   = iou unit
-
 !     output
 !       name    = file name
 !       title   = file title
 !       expnam  = experiment name
 !       timunit = timunit
-!       rlapse  = atmospheric lapse rate
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: name, title, expnam, timunit
+      character(*), intent(out) :: name, title, expnam, timunit
 
-      integer i, iv, ncid
-
-      real rlapse
-      real(kind=4) tmp
+      integer, intent(in) :: ncid
+      integer i
 
       i = nf_get_att_text (ncid, nf_global, 'file_name', name)
       if (i .ne. nf_noerr) print*,'getglobal: file_name not found'
@@ -278,6 +411,84 @@
       return
       end
 
+      subroutine putatttext (ncid, var, name, text)
+!=======================================================================
+!     put text atribute
+
+!     input:
+!       ncid = iou unit
+!       var  = variable name ("global" for a global attribute)
+!       name = text name
+!       text = text
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      include 'netcdf.inc'
+
+      character(*), intent(in) :: var, name, text
+
+      integer, intent(in) :: ncid
+      integer i, iv
+
+      if (var .eq. "global" .or. var .eq. "Global") then
+        i = nf_put_att_text (ncid, nf_global, trim(name)                                                                               &
+     &,   len(trim(text)), trim(text))
+        call checkerror(i,'putatttext global '//trim(name))
+      else
+        i = nf_inq_varid (ncid, var, iv)
+        call checkerror (i,'putatttext nf_inq_varid '//trim(var))
+        i = nf_put_att_text (ncid, iv, trim(name)                                                                               &
+     &,   len(trim(text)), trim(text))
+        call checkerror(i,'putatttext '//trim(var)//' '//trim(name))
+      endif
+
+      return
+      end
+
+      subroutine getatttext (ncid, var, name, text)
+!=======================================================================
+!     get text atribute
+
+!     input:
+!       ncid = iou unit
+!       var  = variable name ("global" for a global attribute)
+!       name = text name
+!     output
+!       text = text
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      include 'netcdf.inc'
+
+      character(*), intent(in) :: var, name
+      character(*), intent(out) :: text
+
+      integer, intent(in) :: ncid
+      integer i, iv
+
+      if (var .eq. "global" .or. var .eq. "Global") then
+        i = nf_get_att_text (ncid, nf_global, trim(name), text)
+        if (i .ne. nf_noerr) then
+          print*,'getatttext: global ',trim(name),' not found'
+        endif
+      else
+        i = nf_inq_varid (ncid, var, iv)
+        call checkerror (i,'getatttext nf_inq_varid '//trim(var))
+        i = nf_get_att_text (ncid, iv, trim(name), text)
+        if (i .ne. nf_noerr) then
+          print*,'getatttext: ',trim(var),' ',trim(name),' not found'
+        endif
+      endif
+
+      return
+      end
+
       subroutine defdim (name, ncid, ln, id)
 !=======================================================================
 !     define dimension
@@ -288,16 +499,17 @@
 !       ln   = length of axis (0 = unlimited)
 !       id   = dimension id
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: name
+      character(*), intent(in) :: name
 
-      integer i, id, ncid, ln
+      integer, intent(in) :: id, ln, ncid
+      integer i
 
       i = nf_inq_dimid (ncid, name, id)
 !     if dimension is already defined, return
@@ -313,6 +525,37 @@
       return
       end
 
+      subroutine getdimlen (name, ncid, ln)
+!=======================================================================
+!     define dimension
+
+!     input:
+!       name = name of dimension
+!       ncid = iou unit
+!     output:
+!       ln   = length of dimension
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      include 'netcdf.inc'
+
+      character(*), intent(in) :: name
+
+      integer, intent(in) :: ncid
+      integer, intent(out) :: ln
+      integer i, id
+
+      i = nf_inq_dimid (ncid, name, id)
+      call checkerror (i,'getdimlen nf_inq_dimid '//name)
+      i = nf_inq_dimlen (ncid, id, ln)
+      call checkerror (i,'getdimlen nf_inq_dimlen '//name)
+
+      return
+      end
+
       subroutine getaxis (name, ncid, ln, dout, is, ie, s, o)
 !=======================================================================
 !     read a netcdf axis
@@ -324,27 +567,32 @@
 
 !     input:
 !       name = name of variable to be defined
-!       ncid = iou unit
+!       ncid = unit
 !       ln   = length of axis
+!       s    = data scalar
+!       o    = data offset
+!     output:
 !       dout = global axis
 !       is   = starting index in global axis
 !       ie   = ending index in global array
-!       s    = data scalar
-!       o    = data offset
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: name
+      character(*), intent(in) :: name
 
-      integer i, id, ie, ncid, is, iv, len, ln
+      integer, intent(in) :: ln, ncid
+      integer, intent(out) :: ie, is
+      integer i, id, iv, len
 
-      real dout(ln), o, rs, s
-      real(kind=4), allocatable :: din(:)
+      real, intent(in) :: o, s
+      real, intent(out) :: dout(ln)
+      real rs
+      real(kind=8), allocatable :: din(:)
 
       i = nf_inq_varid (ncid, name, iv)
       call checkerror (i,'getaxis nf_inq_varid '//name)
@@ -353,8 +601,8 @@
       i = nf_inq_dimlen (ncid, id, len)
       call checkerror (i,'getaxis nf_inq_dimlen '//name)
       allocate (din(len))
-      i = nf_get_vara_real (ncid, iv, 1, len, din)
-      call checkerror(i,'getaxis nf_get_vara_real '//name)
+      i = nf_get_vara_double (ncid, iv, 1, len, din)
+      call checkerror(i,'getaxis nf_get_vara_double '//name)
       is = 0
       do i=ln,1,-1
         if (abs(dout(i)-din(1)) .lt. 1.e-5) is = i
@@ -379,14 +627,14 @@
       return
       end
 
-      subroutine defvar (name, ncid, nd, id, rmin, rmax, axis
+      subroutine defvar (name, ncid, nd, id, rmin, rmax, axis                                                                        &
      &,                  type, lname, sname, units)
 !=======================================================================
 !     define data
 
 !     input:
 !       name  = name of variable to be defined
-!       ncid  = iou unit
+!       ncid  = unit
 !       nd    = number dimensions of data
 !       id    = data id
 !       rmin  = minimum range (default real)
@@ -397,20 +645,21 @@
 !       sname = standard name
 !       units = data units
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: name, axis, lname, sname, type, units
+      character(*), intent(in) :: name, axis, lname, sname, type, units
 
-      integer i, nd, id(nd), idt(nd+1), iv, ncid, ln, rvari(2)
+      integer, intent(in) :: nd, id(nd), ncid
+      integer i, idt(nd+1), iv, ln, ivar(2)
 
-      real rmax, rmin
-      real(kind=4) rvarf(2)
-      real(kind=8) rvard(2)
+      real, intent(in) :: rmax, rmin
+      real(kind=4) fvar(2)
+      real(kind=8) dvar(2)
 
       i = nf_inq_varid (ncid, name, iv)
 !     if variable is already defined, return
@@ -420,15 +669,12 @@
         i = nf_def_var (ncid, name, nf_double, nd, id, iv)
         call checkerror (i,'defvar double '//trim(name))
         if (rmin .ne. rmax) then
-          rvard(1) = dble(rmin)
-          rvard(2) = dble(rmax)
-          i = nf_put_att_double(ncid,iv,'valid_range',nf_double,2,rvard)
+          dvar(1) = dble(rmin)
+          dvar(2) = dble(rmax)
+          i = nf_put_att_double(ncid,iv,'valid_range',nf_double,2,dvar)
           call checkerror(i,'defvar valid_range double '//trim(name))
         endif
-        i = nf_put_att_double (ncid,iv,'fill_value',nf_double,1
-     &,   nf_fill_double)
-        call checkerror (i,'defvar missing_value double '//trim(name))
-        i = nf_put_att_double (ncid,iv,'missing_value',nf_double,1
+        i = nf_put_att_double (ncid,iv,'fill_value',nf_double,1                                                                      &
      &,   nf_fill_double)
         call checkerror (i,'defvar fill_value double '//trim(name))
 
@@ -436,33 +682,27 @@
         i = nf_def_var (ncid, name, nf_real, nd, id, iv)
         call checkerror (i,'defvar real '//name)
         if (rmin .ne. rmax) then
-          rvarf(1) = real(rmin)
-          rvarf(2) = real(rmax)
-          i = nf_put_att_real (ncid,iv,'valid_range',nf_real,2,rvarf)
+          fvar(1) = real(rmin)
+          fvar(2) = real(rmax)
+          i = nf_put_att_real (ncid,iv,'valid_range',nf_real,2,fvar)
           call checkerror (i,'defvar valid_range real '//trim(name))
         endif
-        i = nf_put_att_double (ncid,iv,'fill_value',nf_real,1
+        i = nf_put_att_double (ncid,iv,'fill_value',nf_real,1                                                                        &
      &,   nf_fill_double)
         call checkerror (i,'defvar fill_value real '//trim(name))
-        i = nf_put_att_double (ncid,iv,'missing_value',nf_real,1
-     &,   nf_fill_double)
-        call checkerror (i,'defvar missing_value real '//trim(name))
 
       elseif (type .eq. 'I') then
         i = nf_def_var (ncid, name, nf_int, nd, id, iv)
         call checkerror (i,'defvar integer '//trim(name))
         if (rmin .ne. rmax) then
-          rvari(1) = int(rmin)
-          rvari(2) = int(rmax)
-          i = nf_put_att_int (ncid,iv,'valid_range',nf_int,2,rvari)
+          ivar(1) = int(rmin)
+          ivar(2) = int(rmax)
+          i = nf_put_att_int (ncid,iv,'valid_range',nf_int,2,ivar)
           call checkerror (i,'defvar valid_range integer '//trim(name))
         endif
-        i = nf_put_att_int (ncid,iv,'fill_value',nf_int,1
+        i = nf_put_att_int (ncid,iv,'fill_value',nf_int,1                                                                            &
      &,   nf_fill_int)
         call checkerror (i,'defvar fill_value integer '//trim(name))
-        i = nf_put_att_int (ncid,iv,'missing_value',nf_int,1
-     &,   nf_fill_int)
-        call checkerror (i,'defvar missing_value integer '//trim(name))
 
       elseif (type(1:1) .eq. 'T') then
         ln = 0
@@ -481,6 +721,15 @@
       if (axis .ne. ' ') then
         i = nf_put_att_text (ncid,iv,'axis',len(axis),axis)
         call checkerror (i,'defvar axis '//trim(name))
+        if (axis .ne. 'T') then
+          i = max(len(trim(name))-5,1)
+          ln = len(name)-len(trim(name))
+          if (name(i-ln:len(trim(name))-ln) .ne. '_edges') then
+            i = nf_put_att_text (ncid,iv,'edges'
+     &,       len(trim(name)//"_edges"), trim(name)//"_edges")
+            call checkerror (i,'defvar edges '//trim(name))
+          endif
+        endif
       endif
       if (lname .ne. ' ') then
         i = nf_put_att_text (ncid,iv,'long_name',len(lname),lname)
@@ -513,26 +762,30 @@
 !       s    = data scalar
 !       o    = data offset
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: name
+      character(*), intent(in) :: name
 
-      integer i, ncid, iv, is(10), ic(10), ln, nd
+      integer, intent(in) :: ic(10), is(10), ln, ncid
+      integer i, iv, nd
 
-      real din(ln), dm(ln), o, s
+      real, intent(in) :: din(ln), dm(ln), o, s
+      real rs
       real(kind=8) dout(ln)
 
       i = nf_inq_varid (ncid, name, iv)
       call checkerror (i,'putvaramsk nf_inq_varid '//name)
 
+      rs = 0.0
+      if (s .ne. 0.) rs = 1.0/s
       do i=1,ln
         if (dm(i) .ge. 0.5) then
-          dout(i) = din(i)*s + o
+          dout(i) = (din(i) - o)*rs
         else
           dout(i) = nf_fill_double
         endif
@@ -561,22 +814,26 @@
 !       s    = data scalar
 !       o    = data offset
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: name
+      character(*), intent(in) :: name
 
-      integer i, ncid, iv, is(10), ic(10), ln, nd
+      integer, intent(in) :: is(10), ic(10), ln, ncid
+      integer i, iv, nd
 
-      real din(ln), o, s
+      real, intent(in) :: din(ln), o, s
+      real rs
       real(kind=8) dout(ln)
 
+      rs = 0.0
+      if (s .ne. 0.) rs = 1.0/s
       do i=1,ln
-        dout(i) = din(i)*s + o
+        dout(i) = (din(i) - o)*rs
       enddo
       i = nf_inq_varid (ncid, name, iv)
       call checkerror (i,'putvara nf_inq_varid '//name)
@@ -590,48 +847,134 @@
 
       subroutine getvara (name, ncid, ln, is, ic, dout, s, o)
 !=======================================================================
-!     read real data
+!     read data
 
 !     input:
 !       name = name of variable to be written
 !       ncid = iou unit
 !       ln   = length of data
-!       is   = starting point for write in each dimension
-!       ic   = count (or length) for write in each dimension
-!       dout = data (default real)
+!       is   = starting point for read in each dimension
+!       ic   = count (or length) for read in each dimension
 !       s    = data scalar
 !       o    = data offset
+!     output:
+!       dout = data (default real)
 
-!     author:   m.eby   e-mail: eby@uvic.ca
+!     based on code by: M. Eby
 !=======================================================================
 
       implicit none
 
       include 'netcdf.inc'
 
-      character(*) :: name
+      character(*), intent(in) :: name
 
-      integer i, ncid, iv, is(10), ic(10), ln, nd
+      integer, intent(in) :: is(10), ic(10), ln, ncid
+      integer i, iv, nd
 
-      real(kind=8) din(ln)
-      real dout(ln), o, rs, s
+      real, intent(in) :: o, s
+      real, intent(out) :: dout(ln)
+      real(kind=8) din(ln), offset, scale
+
+      i = nf_inq_varid (ncid, name, iv)
+      if (i .ne. nf_noerr) then
+        print*, '==> Warning: netcdf variable ',trim(name), ' not found'
+        return
+      endif
+      scale = 1.0
+      offset = 0.0
+      i = nf_inq_varndims(ncid, iv, nd)
+      call checkerror (i,'getvara nf_inq_varndims '//name)
+      i = nf_get_att_double (ncid, iv, 'add_offset', offset)
+      i = nf_get_att_double (ncid, iv, 'scale_factor', scale)
+      i = nf_get_vara_double (ncid, iv, is(1:nd), ic(1:nd), din)
+      call checkerror(i,'getvara '//name)
+      dout(1:ln) = (din(1:ln)*scale + offset)*s + o
+
+      return
+      end
+
+      subroutine putvars (name, ncid, is, din, s, o)
+!=======================================================================
+!     write scalar data
+
+!     input:
+!       name = name of variable to be written
+!       ncid = iou unit
+!       is   = starting point for write
+!       din  = data to be written (default real)
+!       s    = data scalar
+!       o    = data offset
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      include 'netcdf.inc'
+
+      character(*), intent(in) :: name
+
+      integer, intent(in) :: ncid, is
+      integer i, iv
+
+      real, intent(in) :: din, o, s
+      real rs
+      real(kind=8) dout
+
+      rs = 0.0
+      if (s .ne. 0.) rs = 1.0/s
+      dout = (din - o)*rs
+      i = nf_inq_varid (ncid, name, iv)
+      call checkerror (i,'putvars nf_inq_varid '//name)
+      i = nf_put_vara_double (ncid, iv, is, 1, dout)
+      call checkerror(i,'putvars '//name)
+
+      return
+      end
+
+      subroutine getvars (name, ncid, is, dout, s, o)
+!=======================================================================
+!     read scalar data
+
+!     input:
+!       name = name of variable to be read
+!       ncid = iou unit
+!       is   = starting point for read
+!       s    = data scalar
+!       o    = data offset
+!     output:
+!       dout = data (default real)
+
+!     based on code by: M. Eby
+!=======================================================================
+
+      implicit none
+
+      include 'netcdf.inc'
+
+      character(*), intent(in) :: name
+
+      integer, intent(in) :: ncid, is
+      integer i, iv
+
+      real, intent(in) :: o, s
+      real, intent(out) :: dout
+      real(kind=8) din, offset, scale
 
       i = nf_inq_varid (ncid, name, iv)
 !     return zero for data if variable is not found
       if (i .ne. nf_noerr) then
-        dout(:) = 0.
         print*, '==> Warning: netcdf variable ',trim(name), ' not found'
         return
       endif
-      i = nf_inq_varndims(ncid, iv, nd)
-      call checkerror (i,'getvara nf_inq_varndims '//name)
-      i = nf_get_vara_double (ncid, iv, is(1:nd), ic(1:nd), din)
+      scale = 1.0
+      offset = 0.0
+      i = nf_get_att_double (ncid, iv, 'add_offset', offset)
+      i = nf_get_att_double (ncid, iv, 'scale_factor', scale)
+      i = nf_get_vara_double (ncid, iv, is, 1, din)
       call checkerror(i,'getvara '//name)
-      rs = 0.0
-      if (s .ne. 0.) rs = 1.0/s
-      do i=1,ln
-        dout(i) = (din(i)- o)*rs
-      enddo
+      dout = (din*scale + offset)*s + o
 
       return
       end
@@ -641,24 +984,22 @@
 !     make edges for grid cells
 
 !     input:
-!       it    = flag for grid (t=1, u=2)
-!       xt    = t grid poistion array
-!       dxt   = t grid width
-!       xu    = u grid poistion array
-!       dxu   = u grid width
-!       imt   = array size
+!       it  = flag for grid (t=1, u=2)
+!       xt  = t grid poistion array
+!       dxt = t grid width
+!       xu  = u grid poistion array
+!       dxu = u grid width
+!       imt = array size
 !     output:
 !       edges = edge array
-
-!     based on GFDL MOM3 code
-
-!     author:   m.eby   e-mail: eby@uvic.ca
 !=======================================================================
 
       implicit none
 
-      integer i, imt, it
-      real edges(0:imt), xt(imt), dxt(imt), xu(imt), dxu(imt)
+      integer, intent(in) :: imt, it
+      integer i
+      real, intent(in) :: xt(imt), dxt(imt), xu(imt), dxu(imt)
+      real, intent(out) :: edges(0:imt)
 
       if (it .eq. 1) then
 !       make edges for T cells
